==> kubernetes-client-5.4.1-sources.jar: io/fabric8/kubernetes/client/RequestConfigFluent.java <==
package io.fabric8.kubernetes.client;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;
import java.util.LinkedHashMap;

public interface RequestConfigFluent<A extends io.fabric8.kubernetes.client.RequestConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public java.lang.String getUsername();
    public A withUsername(java.lang.String username);
    public java.lang.Boolean hasUsername();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withUsername instead.
     */
        public A withNewUsername(java.lang.String arg0);
    public java.lang.String getPassword();
    public A withPassword(java.lang.String password);
    public java.lang.Boolean hasPassword();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withPassword instead.
     */
        public A withNewPassword(java.lang.String arg0);
    public java.lang.String getOauthToken();
    public A withOauthToken(java.lang.String oauthToken);
    public java.lang.Boolean hasOauthToken();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withOauthToken instead.
     */
        public A withNewOauthToken(java.lang.String arg0);
    public io.fabric8.kubernetes.client.OAuthTokenProvider getOauthTokenProvider();
    public A withOauthTokenProvider(io.fabric8.kubernetes.client.OAuthTokenProvider oauthTokenProvider);
    public java.lang.Boolean hasOauthTokenProvider();
    public java.lang.String getImpersonateUsername();
    public A withImpersonateUsername(java.lang.String impersonateUsername);
    public java.lang.Boolean hasImpersonateUsername();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withImpersonateUsername instead.
     */
        public A withNewImpersonateUsername(java.lang.String arg0);
    public A withImpersonateGroups(java.lang.String... impersonateGroups);
    public java.lang.String[] getImpersonateGroups();
    public A addToImpersonateGroups(int index,java.lang.String item);
    public A setToImpersonateGroups(int index,java.lang.String item);
    public A addToImpersonateGroups(java.lang.String... items);
    public A addAllToImpersonateGroups(java.util.Collection<java.lang.String> items);
    public A removeFromImpersonateGroups(java.lang.String... items);
    public A removeAllFromImpersonateGroups(java.util.Collection<java.lang.String> items);
    public java.lang.Boolean hasImpersonateGroups();
    public A addNewImpersonateGroup(java.lang.String arg0);
    public A addToImpersonateExtras(java.lang.String key,java.util.List<java.lang.String> value);
    public A addToImpersonateExtras(java.util.Map<java.lang.String,java.util.List<java.lang.String>> map);
    public A removeFromImpersonateExtras(java.lang.String key);
    public A removeFromImpersonateExtras(java.util.Map<java.lang.String,java.util.List<java.lang.String>> map);
    public java.util.Map<java.lang.String,java.util.List<java.lang.String>> getImpersonateExtras();
    public <K,V>A withImpersonateExtras(java.util.Map<java.lang.String,java.util.List<java.lang.String>> impersonateExtras);
    public java.lang.Boolean hasImpersonateExtras();
    public int getWatchReconnectInterval();
    public A withWatchReconnectInterval(int watchReconnectInterval);
    public java.lang.Boolean hasWatchReconnectInterval();
    public int getWatchReconnectLimit();
    public A withWatchReconnectLimit(int watchReconnectLimit);
    public java.lang.Boolean hasWatchReconnectLimit();
    public int getConnectionTimeout();
    public A withConnectionTimeout(int connectionTimeout);
    public java.lang.Boolean hasConnectionTimeout();
    public int getRequestTimeout();
    public A withRequestTimeout(int requestTimeout);
    public java.lang.Boolean hasRequestTimeout();
    public long getRollingTimeout();
    public A withRollingTimeout(long rollingTimeout);
    public java.lang.Boolean hasRollingTimeout();
    public long getScaleTimeout();
    public A withScaleTimeout(long scaleTimeout);
    public java.lang.Boolean hasScaleTimeout();
    public int getLoggingInterval();
    public A withLoggingInterval(int loggingInterval);
    public java.lang.Boolean hasLoggingInterval();
    public long getWebsocketTimeout();
    public A withWebsocketTimeout(long websocketTimeout);
    public java.lang.Boolean hasWebsocketTimeout();
    public long getWebsocketPingInterval();
    public A withWebsocketPingInterval(long websocketPingInterval);
    public java.lang.Boolean hasWebsocketPingInterval();
    public int getMaxConcurrentRequests();
    public A withMaxConcurrentRequests(int maxConcurrentRequests);
    public java.lang.Boolean hasMaxConcurrentRequests();
    public int getMaxConcurrentRequestsPerHost();
    public A withMaxConcurrentRequestsPerHost(int maxConcurrentRequestsPerHost);
    public java.lang.Boolean hasMaxConcurrentRequestsPerHost();
}

==> kubernetes-client-5.6.0-sources.jar: io/fabric8/kubernetes/client/RequestConfigFluent.java <==
package io.fabric8.kubernetes.client;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;
import java.util.LinkedHashMap;

public interface RequestConfigFluent<A extends io.fabric8.kubernetes.client.RequestConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public java.lang.String getUsername();
    public A withUsername(java.lang.String username);
    public java.lang.Boolean hasUsername();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withUsername instead.
     */
        public A withNewUsername(java.lang.String arg0);
    public java.lang.String getPassword();
    public A withPassword(java.lang.String password);
    public java.lang.Boolean hasPassword();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withPassword instead.
     */
        public A withNewPassword(java.lang.String arg0);
    public java.lang.String getOauthToken();
    public A withOauthToken(java.lang.String oauthToken);
    public java.lang.Boolean hasOauthToken();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withOauthToken instead.
     */
        public A withNewOauthToken(java.lang.String arg0);
    public io.fabric8.kubernetes.client.OAuthTokenProvider getOauthTokenProvider();
    public A withOauthTokenProvider(io.fabric8.kubernetes.client.OAuthTokenProvider oauthTokenProvider);
    public java.lang.Boolean hasOauthTokenProvider();
    public java.lang.String getImpersonateUsername();
    public A withImpersonateUsername(java.lang.String impersonateUsername);
    public java.lang.Boolean hasImpersonateUsername();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withImpersonateUsername instead.
     */
        public A withNewImpersonateUsername(java.lang.String arg0);
    public A withImpersonateGroups(java.lang.String... impersonateGroups);
    public java.lang.String[] getImpersonateGroups();
    public A addToImpersonateGroups(int index,java.lang.String item);
    public A setToImpersonateGroups(int index,java.lang.String item);
    public A addToImpersonateGroups(java.lang.String... items);
    public A addAllToImpersonateGroups(java.util.Collection<java.lang.String> items);
    public A removeFromImpersonateGroups(java.lang.String... items);
    public A removeAllFromImpersonateGroups(java.util.Collection<java.lang.String> items);
    public java.lang.Boolean hasImpersonateGroups();
    public A addNewImpersonateGroup(java.lang.String arg0);
    public A addToImpersonateExtras(java.lang.String key,java.util.List<java.lang.String> value);
    public A addToImpersonateExtras(java.util.Map<java.lang.String,java.util.List<java.lang.String>> map);
    public A removeFromImpersonateExtras(java.lang.String key);
    public A removeFromImpersonateExtras(java.util.Map<java.lang.String,java.util.List<java.lang.String>> map);
    public java.util.Map<java.lang.String,java.util.List<java.lang.String>> getImpersonateExtras();
    public <K,V>A withImpersonateExtras(java.util.Map<java.lang.String,java.util.List<java.lang.String>> impersonateExtras);
    public java.lang.Boolean hasImpersonateExtras();
    public int getWatchReconnectInterval();
    public A withWatchReconnectInterval(int watchReconnectInterval);
    public java.lang.Boolean hasWatchReconnectInterval();
    public int getWatchReconnectLimit();
    public A withWatchReconnectLimit(int watchReconnectLimit);
    public java.lang.Boolean hasWatchReconnectLimit();
    public int getConnectionTimeout();
    public A withConnectionTimeout(int connectionTimeout);
    public java.lang.Boolean hasConnectionTimeout();
    public int getUploadConnectionTimeout();
    public A withUploadConnectionTimeout(int uploadConnectionTimeout);
    public java.lang.Boolean hasUploadConnectionTimeout();
    public int getUploadRequestTimeout();
    public A withUploadRequestTimeout(int uploadRequestTimeout);
    public java.lang.Boolean hasUploadRequestTimeout();
    public int getRequestRetryBackoffLimit();
    public A withRequestRetryBackoffLimit(int requestRetryBackoffLimit);
    public java.lang.Boolean hasRequestRetryBackoffLimit();
    public int getRequestRetryBackoffInterval();
    public A withRequestRetryBackoffInterval(int requestRetryBackoffInterval);
    public java.lang.Boolean hasRequestRetryBackoffInterval();
    public int getRequestTimeout();
    public A withRequestTimeout(int requestTimeout);
    public java.lang.Boolean hasRequestTimeout();
    public long getRollingTimeout();
    public A withRollingTimeout(long rollingTimeout);
    public java.lang.Boolean hasRollingTimeout();
    public long getScaleTimeout();
    public A withScaleTimeout(long scaleTimeout);
    public java.lang.Boolean hasScaleTimeout();
    public int getLoggingInterval();
    public A withLoggingInterval(int loggingInterval);
    public java.lang.Boolean hasLoggingInterval();
    public long getWebsocketTimeout();
    public A withWebsocketTimeout(long websocketTimeout);
    public java.lang.Boolean hasWebsocketTimeout();
    public long getWebsocketPingInterval();
    public A withWebsocketPingInterval(long websocketPingInterval);
    public java.lang.Boolean hasWebsocketPingInterval();
    public int getMaxConcurrentRequests();
    public A withMaxConcurrentRequests(int maxConcurrentRequests);
    public java.lang.Boolean hasMaxConcurrentRequests();
    public int getMaxConcurrentRequestsPerHost();
    public A withMaxConcurrentRequestsPerHost(int maxConcurrentRequestsPerHost);
    public java.lang.Boolean hasMaxConcurrentRequestsPerHost();
}
